@@ -4,19 +4,29 @@ use strict;
 
 BEGIN {
     use vars qw(@ISA);
-    @ISA = qw( Excel::Template::Container::Format );
+    @ISA = qw( Excel::Template::Container );
 
-    use Excel::Template::Container::Format;
+    use Excel::Template::Container;
 }
 
-sub new
+use Excel::Template::Format;
+
+sub render
 {
-    my $class = shift;
-    my $self = $class->SUPER::new(@_);
+    my $self = shift;
+    my ($context) = @_;
 
-    $self->{BOLD} = 1;
+    my $old_format = $context->active_format;
+    my $format = Excel::Template::Format->copy(
+        $context, $old_format,
 
-    return $self;
+        bold => 1,
+    );
+    $context->active_format($format);
+
+    my $child_success = $self->iterate_over_children($context);
+
+    $context->active_format($old_format);
 }
 
 1;
@@ -36,7 +46,7 @@ BOLD
 
 =head1 INHERITANCE
 
-Excel::Template::Container::Format
+Excel::Template::Container
 
 =head1 ATTRIBUTES
 
@@ -56,9 +66,11 @@ None
 
 =head1 USAGE
 
-  <bold>
+<bold>
+
     ... Children here
-  </bold>
+
+</bold>
 
 In the above example, the children will be displayed (if they are displaying
 elements) in a bold format. All other formatting will remain the same and the
@@ -66,10 +78,10 @@ elements) in a bold format. All other formatting will remain the same and the
 
 =head1 AUTHOR
 
-Rob Kinyon (rob.kinyon@gmail.com)
+Rob Kinyon (rkinyon@columbus.rr.com)
 
 =head1 SEE ALSO
 
-FORMAT
+ITALIC
 
 =cut
